#
# spec file for package libdatrie
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libdatrie
Version:        0.2.13
Release:        1.14
Summary:        Double-Array Trie Library
License:        LGPL-2.1-only
Group:          Development/Libraries/C and C++
URL:            https://linux.thai.net/~thep/datrie/datrie.html
Source:         https://linux.thai.net/pub/thailinux/software/libthai/%{name}-%{version}.tar.xz
Source99:       baselibs.conf
BuildRequires:  autoconf-archive
BuildRequires:  doxygen
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  xz

%description
This is an implementation of double-array structure for representing
trie, as proposed by Junichi Aoe.

%package -n libdatrie1
Summary:        Double-Array Trie Library
Group:          System/Libraries

%description -n libdatrie1
This is an implementation of double-array structure for representing
trie, as proposed by Junichi Aoe.

%package devel
Summary:        Development files for the Double-Array Trie library
Group:          Development/Libraries/C and C++
Requires:       libdatrie1 = %{version}

%description devel
This is an implementation of double-array structure for representing
trie, as proposed by Junichi Aoe.

This package contains the development files for libdatrie.

%prep
%setup -q

%build
autoreconf -fiv
%configure \
        --disable-static \
        --with-html-docdir=%{_docdir}/libdatrie/html
%make_build

%install
%make_install
rm -f %{buildroot}%{_libdir}/libdatrie.la

%post -n libdatrie1 -p /sbin/ldconfig
%postun -n libdatrie1 -p /sbin/ldconfig

%files -n libdatrie1
%license COPYING
%doc AUTHORS ChangeLog README
%{_libdir}/libdatrie.so.1*

%files devel
%doc README.migration
%doc %{_docdir}/libdatrie
%{_bindir}/trietool*
%{_mandir}/man*/trietool*.1%{?ext_man}
%{_includedir}/datrie/
%{_libdir}/libdatrie.so
%{_libdir}/pkgconfig/datrie-0.2.pc

%changelog
* Thu Feb 11 2021 Dirk Müller <dmueller@suse.com>
- update to 0.2.13:
  - Fix wrong key listing in byte trie
  - Fix cross-compiling issue caused by AC_FUNC_MALLOC
  - Fix isspace() arg problem on NetBSD.
  - Fix some documentations.
  - Really use TRIE_CHAR_TERM in TrieChar string termination.
    Changing TRIE_CHAR_TERM definition now won't break the code.
  - Fix Windows build issue by avoiding <unistd.h> include.
  - [New APIs] Add serialization of the trie into memory buffer.
* Tue Aug 25 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.2.12:
  - More C90 (ANSI C) compliance.
  - Prevent some compiling conflicts with other sources.
  - Fix miscellaneous compiler warnings.
  - Prevent trimming on extremely long dictionary path names.
  - Detect iconv() error more correctly in trietool.
  - Clarify package description that search time is O(m), where m is
    key length, not O(1), while still claiming that it's independent
    of database size.
  - Fix trie_state_get_data() on a prefix key.
  - Fix reported segfault on full-range alpha map.
* Mon Feb 19 2018 jengelh@inai.de
- Fix RPM groups. Remove ineffective --with-pic.
* Sun Feb 18 2018 avindra@opensuse.org
- update to version 0.2.10
  * Correctly check doxygen version on configure
  * Optimization on AlphaMap mapping
- remove libdatrie-doxygen-version-check.patch
  * upstreamed in 7db54c662357dba5f109eaf1b24490f46ca23d44
- use https urls
* Tue Aug 18 2015 pgajdos@suse.com
- update to version 0.2.9
  * Fix infinite loop on empty trie iteration.
  * Document about alphabet size.
  * Disable timestamp in Doxygen-generated doc.
  * etc. see ChangeLog
- remove libdatrie-doxygen-found-is-enough.patch in favour of
  libdatrie-doxygen-version-check.patch
* Tue Aug 18 2015 dimstar@opensuse.org
- Add libdatrie-doxygen-found-is-enough.patch: when we find
  doxygen, we assume it is new enough. The configure script uses
  'expr 1.8.4 \< $DOXYGEN_VER', which returns false for 1.8.10.
- For safeguard, we specify the minimal required version of
  doxygen (1.8.4) in the buildrequirements.
* Wed Feb  4 2015 p.drouand@gmail.com
- Update to version 0.2.8
  * Fix compiler warnings in test suites.
  * Fix edge-case error on alphabet set of size 255.
  * Fail trie operations on non-alphabet inputs, rather than silently
    allowing them to sneak in as false keys.
  * Improved documentation.
- Add xz build require to keep SLE11 support
* Thu Apr 11 2013 mmeister@suse.com
- Added url as source.
  Please see http://en.opensuse.org/SourceUrls
* Wed Feb  1 2012 jengelh@medozas.de
- Remove redundant tags/sections per specfile guideline suggestions
- Parallel building using %%_smp_mflags
* Wed Feb 23 2011 vuntz@opensuse.org
- Add missing baselibs.conf.
* Sun Sep 19 2010 vuntz@opensuse.org
- Update to version 0.2.4:
  + Close file on saving trie.
  + Add trie_store_if_absent() API which fails on adding duplicated
    key. This is useful for preventing race condition in
    multi-thread applications.
  + Add trie_fread() and trie_fwrite() APIs for reading/writing
    trie data in an open file, allowing trie to be embeded as part
    of a bigger file.
- Changes from version 0.2.3:
  + More robustness against corrupted trie files.
  + License clarification in individual source files.
* Sat Apr 24 2010 coolo@novell.com
- buildrequire pkg-config to fix provides
* Mon Jan  4 2010 vuntz@opensuse.org
- Update to version 0.2.2:
  + Support building with linkers without symbol versioning
    supports, including Mac, Cygwin, MinGW.
  + Support other iconv implementations than that's in glibc, for
    Mac and MinGW.
- Changes from version 0.2.1:
  + Fix errors in documentation
  + Symbol versioning to ease upgrade across SONAME
  + Minor cleanups
- Changes from version 0.2.0:
  + New APIs for performance: trie_state_copy(),
    trie_state_is_single()
  + Clean-ups
- Changes from version 0.1.99.2:
  + More robust handling of alphabet ranges
  + Allow co-existence with libdatrie0
- Changes from version 0.1.99.1:
  + Breaking ABI with libdatrie0
  + More capacity with 32-bit node index
  + Adjusted API for non-file trie usage
  + All data in one file, no more *.br and *.tl split
  + Drop SBTrie wrapper; all features are merged into Trie
  + Domain characters are now Unicode
* Thu Feb 19 2009 crrodriguez@suse.de
- remove static libraries
* Mon Apr  7 2008 uli@suse.de
- update -> 0.1.3 (fixes bug that keeps new libthai from
  building, bnc #326002)
* Tue Oct 30 2007 uli@suse.de
- initial package
